==> bootstrap_storybook-8.x-1.0.tar.gz: bootstrap_storybook/webpack.mix.js <==
/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your application. See https://github.com/JeffreyWay/laravel-mix.
 |
 */
// Imports the proxy from config.json to avoid conflicts
const proxy = require('./config/config.js');
const mix = require('laravel-mix');

/*
 |--------------------------------------------------------------------------
 | Configuration
 |--------------------------------------------------------------------------
 */
mix
  .setPublicPath('assets')
  .disableNotifications()
  .options({
    processCssUrls: false
  });

/*
 |--------------------------------------------------------------------------
 | Browsersync
 |--------------------------------------------------------------------------
 */
mix.browserSync({
  proxy: proxy.proxy,
  files: ['assets/js/**/*.js', 'assets/css/**/*.css'],
  stream: true,
});

/*
 |--------------------------------------------------------------------------
 | SASS
 |--------------------------------------------------------------------------
 */
// General CSS file
mix.sass('src/sass/bootstrap_storybook.style.scss', 'css');

/*
 |--------------------------------------------------------------------------
 | JS
 |--------------------------------------------------------------------------
 */
// All the necessary JS
mix.js('src/js/bootstrap_storybook.script.js', 'js');

/*
 |--------------------------------------------------------------------------
 | IMAGES / ICONS
 |--------------------------------------------------------------------------
 */
// Directly copies the image or the icon, does not do anything on the image
mix.copy('src/images/', 'assets/images');
mix.copy('src/icons/', 'assets/icons');

==> bootstrap_storybook-8.x-1.1.tar.gz: bootstrap_storybook/webpack.mix.js <==
/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your application. See https://github.com/JeffreyWay/laravel-mix.
 |
 */
// Imports the proxy from config.js to avoid conflicts
let mix = require('laravel-mix');
let proxy = require('./config/config.js');
require('laravel-mix-copy-watched');

/*
 |--------------------------------------------------------------------------
 | Configuration
 |--------------------------------------------------------------------------
 */
mix
  .setPublicPath('assets')
  .disableNotifications()
  .options({
    processCssUrls: false
  });

/*
 |--------------------------------------------------------------------------
 | Browsersync
 |--------------------------------------------------------------------------
 */
mix.browserSync({
  proxy: proxy.proxy,
  files: ['assets/js/**/*.js', 'assets/css/**/*.css'],
  stream: true,
});

/*
 |--------------------------------------------------------------------------
 | SASS
 |--------------------------------------------------------------------------
 */
// General CSS file
mix.sass('src/sass/bootstrap_storybook.style.scss', 'css');

/*
 |--------------------------------------------------------------------------
 | JS
 |--------------------------------------------------------------------------
 */
mix.js('src/js/bootstrap_storybook.script.js', 'js');

/*
 |--------------------------------------------------------------------------
 | IMAGES / ICONS
 |--------------------------------------------------------------------------
 */
// Directly copies the image or the icon, does not do anything on the image
mix.copyDirectoryWatched('src/images', 'assets/images');
mix.copyDirectoryWatched('src/icons', 'assets/icons');
